﻿using System;
using System.Collections.Generic;
using System.Text;

namespace SeqSharp
{
    /// <summary>
    /// SeqSharpアプリケーションで使用するファイル情報クラスです。
    /// </summary>
    public class MyFileInfo
    {
        /// <summary>
        /// ファイル情報
        /// </summary>
        private System.IO.FileInfo fileInfo;
    
        /// <summary>
        /// ファイル情報クラスを作成します。
        /// </summary>
        /// <param name="fileInfo"></param>
        public MyFileInfo(System.IO.FileInfo fileInfo)
        {
            this.fileInfo = fileInfo;
        }

        /// <summary>
        /// ファイル名です。
        /// </summary>
        public string Name
        {
            get
            {
                return fileInfo.Name;
            }
        }

        /// <summary>
        /// ファイル名のフルパスを返します。
        /// </summary>
        public string FullName
        {
            get
            {
                return fileInfo.FullName;
            }
        }

        /// <summary>
        /// ファイル名の拡張子を返します。
        /// </summary>
        public string Extension
        {
            get
            {
                return fileInfo.Extension;
            }
        }

        /// <summary>
        /// ファイルが存在するかどうかを返します。
        /// </summary>
        public bool Exists
        {
            get
            {
                return new System.IO.FileInfo(FullName).Exists;
            }
        }

        /// <summary>
        /// このファイル情報の文字列表現を返します。
        /// </summary>
        /// <returns>ファイル情報の文字列表現</returns>
        public override string ToString()
        {
            return Name;
        }
    }
}
